@@ -25,6 +25,7 @@ from exasol.toolbox.sphinx.multiversion import (
     git,
     sphinx,
 )
+from exasol.toolbox.util.version import Version as ExasolVersion
 
 logging.basicConfig(
     level="INFO",
@@ -58,7 +59,7 @@ def load_sphinx_config_worker(q, confpath, confoverrides, add_defaults):
             )
             current_config.add(
                 "smv_branch_whitelist",
-                sphinx.DEFAULT_TAG_WHITELIST,
+                sphinx.DEFAULT_BRANCH_WHITELIST,
                 "html",
                 str,
             )
@@ -227,6 +228,11 @@ def _create_parser():
         action="store_true",
         help="dump generated metadata and exit",
     )
+    parser.add_argument(
+        "--debug",
+        action="store_true",
+        help="enable debug mode with increased log verbosity, etc.",
+    )
     return parser
 
 
@@ -246,6 +252,8 @@ def main(argv=None):
 
 
 def _main(args, argv):
+    if args.debug:
+        logger.setLevel(logging.DEBUG)
     sourcedir_absolute = os.path.abspath(args.sourcedir)
     confdir_absolute = (
         os.path.abspath(args.confdir)
@@ -278,12 +286,14 @@ def _main(args, argv):
     conffile = os.path.join(confdir, "conf.py")
 
     # Get git references
-    gitrefs = git.get_refs(
-        str(gitroot),
-        config.smv_tag_whitelist,
-        config.smv_branch_whitelist,
-        config.smv_remote_whitelist,
-        files=(sourcedir, conffile),
+    gitrefs = list(
+        git.get_refs(
+            str(gitroot),
+            config.smv_tag_whitelist,
+            config.smv_branch_whitelist,
+            config.smv_remote_whitelist,
+            files=(sourcedir, conffile),
+        )
     )
 
     # Order git refs
@@ -371,7 +381,7 @@ def _main(args, argv):
 
         # Write Metadata
         metadata_path = os.path.abspath(os.path.join(tmp, "versions.json"))
-        with open(metadata_path, mode="w") as fp:
+        with open(metadata_path, mode="w", encoding="utf-8") as fp:
             json.dump(metadata, fp, indent=2)
 
         # Run Sphinx
@@ -566,12 +576,33 @@ def _main(args, argv):
                     export_to_destination(matches, export_dst)
 
         with resources.path(
-            "exasol.sphinx_extensions.multiversion.templates", "multiversion-index.html"
+            "exasol.toolbox.sphinx.multiversion.templates", "multiversion-index.html"
         ) as p:
-            with open(p) as f:
+            with open(p, encoding="utf-8") as f:
                 template = Template(f.read())
-            with open(os.path.join(args.outputdir, "index.html"), "w") as f:
-                ref = gitrefs[-1]
-                f.write(template.render(version=ref.name))
+            with open(
+                os.path.join(args.outputdir, "index.html"), "w", encoding="utf-8"
+            ) as f:
+                logger.debug(
+                    "Picked up Git references: %s", [ref.name for ref in gitrefs]
+                )
+                tag_versions = [
+                    ref.name
+                    for ref in gitrefs
+                    if re.match(config.smv_tag_whitelist, ref.name)
+                ]
+                tag_versions = sorted(
+                    tag_versions,
+                    key=lambda v: ExasolVersion.from_string(v),
+                    reverse=True,
+                )
+                branches = [
+                    ref.name
+                    for ref in gitrefs
+                    if re.match(config.smv_branch_whitelist, ref.name)
+                ]
+                versions = branches + tag_versions
+                logger.debug("Selected versions for documentation: %s", versions)
+                f.write(template.render(version=versions[0]))
 
     return 0
